@@ -16,26 +16,62 @@ from twitchdl.exceptions import ConsoleError
 from twitchdl.output import print_out, print_video
 
 
-def videos(channel_name, limit, offset, sort, type, **kwargs):
-    print_out("Looking up user...")
-    user = twitch.get_user(channel_name)
-    if not user:
-        raise ConsoleError("User {} not found.".format(channel_name))
+def _continue():
+    print_out(
+        "\nThere are more videos. "
+        "Press <green><b>Enter</green> to continue, "
+        "<yellow><b>Ctrl+C</yellow> to break."
+    )
 
-    print_out("Loading videos...")
-    videos = twitch.get_channel_videos(user["id"], limit, offset, sort, type)
-    count = len(videos['videos'])
-    if not count:
-        print_out("No videos found")
-        return
+    try:
+        input()
+    except KeyboardInterrupt:
+        return False
 
-    first = offset + 1
-    last = offset + len(videos['videos'])
-    total = videos["_total"]
-    print_out("<yellow>Showing videos {}-{} of {}</yellow>".format(first, last, total))
+    return True
 
-    for video in videos['videos']:
-        print_video(video)
+
+def _get_game_ids(names):
+    if not names:
+        return []
+
+    game_ids = []
+    for name in names:
+        print_out("<dim>Looking up game '{}'...</dim>".format(name))
+        game_id = twitch.get_game_id(name)
+        if not game_id:
+            raise ConsoleError("Game '{}' not found".format(name))
+        game_ids.append(int(game_id))
+
+    return game_ids
+
+
+def videos(channel_name, limit, sort, type, game, **kwargs):
+    game_ids = _get_game_ids(game)
+
+    print_out("<dim>Loading videos...</dim>")
+    generator = twitch.channel_videos_generator(
+        channel_name, limit, sort, type, game_ids=game_ids)
+
+    first = 1
+
+    for videos, has_more in generator:
+        count = len(videos["edges"]) if "edges" in videos else 0
+        total = videos["totalCount"]
+        last = first + count - 1
+
+        print_out("-" * 80)
+        print_out("<yellow>Showing videos {}-{} of {}</yellow>".format(first, last, total))
+
+        for video in videos["edges"]:
+            print_video(video["node"])
+
+        if not has_more or not _continue():
+            break
+
+        first += count
+    else:
+        print_out("<yellow>No videos found</yellow>")
 
 
 def _select_quality(playlists):
@@ -138,7 +174,7 @@ def download(video, **kwargs):
 
 
 def _download_clip(slug, **kwargs):
-    print_out("Looking up clip...")
+    print_out("<dim>Looking up clip...</dim>")
     clip = twitch.get_clip(slug)
 
     print_out("Found: <green>{}</green> by <yellow>{}</yellow>, playing <blue>{}</blue> ({})".format(
@@ -175,21 +211,21 @@ def _download_video(video_id, max_workers, format='mkv', start=None, end=None, k
     if start and end and end <= start:
         raise ConsoleError("End time must be greater than start time")
 
-    print_out("Looking up video...")
+    print_out("<dim>Looking up video...</dim>")
     video = twitch.get_video(video_id)
 
     print_out("Found: <blue>{}</blue> by <yellow>{}</yellow>".format(
         video['title'], video['channel']['display_name']))
 
-    print_out("Fetching access token...")
+    print_out("<dim>Fetching access token...</dim>")
     access_token = twitch.get_access_token(video_id)
 
-    print_out("Fetching playlists...")
+    print_out("<dim>Fetching playlists...</dim>")
     playlists = twitch.get_playlists(video_id, access_token)
     parsed = m3u8.loads(playlists)
     selected = _select_quality(parsed.playlists)
 
-    print_out("\nFetching playlist...")
+    print_out("<dim>\nFetching playlist...</dim>")
     response = requests.get(selected.uri)
     response.raise_for_status()
     playlist = m3u8.loads(response.text)
