@@ -7,6 +7,7 @@ from collections import namedtuple
 
 from twitchdl.exceptions import ConsoleError
 from twitchdl.output import print_err
+from twitchdl.twitch import GQLError
 from . import commands, __version__
 
 
@@ -32,6 +33,19 @@ def time(value):
     return hours * 3600 + minutes * 60 + seconds
 
 
+def limit(value):
+    """Validates the number of videos to fetch."""
+    try:
+        value = int(value)
+    except ValueError:
+        raise ArgumentTypeError("must be an integer")
+
+    if not 1 <= int(value) <= 100:
+        raise ArgumentTypeError("must be between 1 and 100")
+
+    return value
+
+
 COMMANDS = [
     Command(
         name="videos",
@@ -41,16 +55,16 @@ COMMANDS = [
                 "help": "channel name",
                 "type": str,
             }),
+            (["-g", "--game"], {
+                "help": "Show videos of given game (can be given multiple times)",
+                "action": "append",
+                "type": str,
+            }),
             (["-l", "--limit"], {
                 "help": "Number of videos to fetch (default 10, max 100)",
-                "type": int,
+                "type": limit,
                 "default": 10,
             }),
-            (["-o", "--offset"], {
-                "help": "Offset for pagination of results. (default 0)",
-                "type": int,
-                "default": 0,
-            }),
             (["-s", "--sort"], {
                 "help": "Sorting order of videos. (default: time)",
                 "type": str,
@@ -155,3 +169,8 @@ def main():
     except ConsoleError as e:
         print_err(e)
         sys.exit(1)
+    except GQLError as e:
+        print_err(e)
+        for err in e.errors:
+            print_err("*", err["message"])
+        sys.exit(1)
